@@ -140,6 +140,9 @@ impl SearchBase {
 }
 
 pub fn score(str: &str, pattern: &str) -> Option<f32> {
+    if str.is_empty() || pattern.is_empty() {
+        return None;
+    }
     let line_info = LineInfo::new(str, 0.0);
     let composed: Vec<char> = pattern.nfkc().filter(|ch| !ch.is_whitespace()).collect();
     line_info.score(&composed)
